# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupArgs', 'Group']

@pulumi.input_type
class GroupArgs:
    def __init__(__self__, *,
                 group_name: pulumi.Input[builtins.str],
                 join_type: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMemberArgs']]]] = None):
        """
        The set of arguments for constructing a Group resource.
        :param pulumi.Input[builtins.str] group_name: 用户组名称。
        :param pulumi.Input[builtins.str] join_type: 用户组类型。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] display_name: 显示名。
        """
        pulumi.set(__self__, "group_name", group_name)
        pulumi.set(__self__, "join_type", join_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if members is not None:
            pulumi.set(__self__, "members", members)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Input[builtins.str]:
        """
        用户组名称。
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="joinType")
    def join_type(self) -> pulumi.Input[builtins.str]:
        """
        用户组类型。
        """
        return pulumi.get(self, "join_type")

    @join_type.setter
    def join_type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "join_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        显示名。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupMemberArgs']]]]:
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMemberArgs']]]]):
        pulumi.set(self, "members", value)


@pulumi.input_type
class _GroupState:
    def __init__(__self__, *,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 group_id: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 join_type: Optional[pulumi.Input[builtins.str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMemberArgs']]]] = None,
                 source: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Group resources.
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] display_name: 显示名。
        :param pulumi.Input[builtins.str] group_id: 用户组id。
        :param pulumi.Input[builtins.str] group_name: 用户组名称。
        :param pulumi.Input[builtins.str] join_type: 用户组类型。
        :param pulumi.Input[builtins.str] source: 用户组来源。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if group_name is not None:
            pulumi.set(__self__, "group_name", group_name)
        if join_type is not None:
            pulumi.set(__self__, "join_type", join_type)
        if members is not None:
            pulumi.set(__self__, "members", members)
        if source is not None:
            pulumi.set(__self__, "source", source)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        显示名。
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组id。
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组名称。
        """
        return pulumi.get(self, "group_name")

    @group_name.setter
    def group_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "group_name", value)

    @property
    @pulumi.getter(name="joinType")
    def join_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组类型。
        """
        return pulumi.get(self, "join_type")

    @join_type.setter
    def join_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "join_type", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupMemberArgs']]]]:
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupMemberArgs']]]]):
        pulumi.set(self, "members", value)

    @property
    @pulumi.getter
    def source(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户组来源。
        """
        return pulumi.get(self, "source")

    @source.setter
    def source(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:cloudidentity/group:Group")
class Group(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 join_type: Optional[pulumi.Input[builtins.str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupMemberArgs', 'GroupMemberArgsDict']]]]] = None,
                 __props__=None):
        """
        当您需要批量为云身份中心用户进行SSO授权时，您可以先通过用户组进行批量的用户管理。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cloudidentity/group:Group example "group_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] display_name: 显示名。
        :param pulumi.Input[builtins.str] group_name: 用户组名称。
        :param pulumi.Input[builtins.str] join_type: 用户组类型。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        当您需要批量为云身份中心用户进行SSO授权时，您可以先通过用户组进行批量的用户管理。

        ## Import

        ```sh
        $ pulumi import bytepluscc:cloudidentity/group:Group example "group_id"
        ```

        :param str resource_name: The name of the resource.
        :param GroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 group_name: Optional[pulumi.Input[builtins.str]] = None,
                 join_type: Optional[pulumi.Input[builtins.str]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupMemberArgs', 'GroupMemberArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupArgs.__new__(GroupArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["display_name"] = display_name
            if group_name is None and not opts.urn:
                raise TypeError("Missing required property 'group_name'")
            __props__.__dict__["group_name"] = group_name
            if join_type is None and not opts.urn:
                raise TypeError("Missing required property 'join_type'")
            __props__.__dict__["join_type"] = join_type
            __props__.__dict__["members"] = members
            __props__.__dict__["created_time"] = None
            __props__.__dict__["group_id"] = None
            __props__.__dict__["source"] = None
            __props__.__dict__["updated_time"] = None
        super(Group, __self__).__init__(
            'bytepluscc:cloudidentity/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            group_id: Optional[pulumi.Input[builtins.str]] = None,
            group_name: Optional[pulumi.Input[builtins.str]] = None,
            join_type: Optional[pulumi.Input[builtins.str]] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupMemberArgs', 'GroupMemberArgsDict']]]]] = None,
            source: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'Group':
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 描述。
        :param pulumi.Input[builtins.str] display_name: 显示名。
        :param pulumi.Input[builtins.str] group_id: 用户组id。
        :param pulumi.Input[builtins.str] group_name: 用户组名称。
        :param pulumi.Input[builtins.str] join_type: 用户组类型。
        :param pulumi.Input[builtins.str] source: 用户组来源。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupState.__new__(_GroupState)

        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["group_name"] = group_name
        __props__.__dict__["join_type"] = join_type
        __props__.__dict__["members"] = members
        __props__.__dict__["source"] = source
        __props__.__dict__["updated_time"] = updated_time
        return Group(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[builtins.str]:
        """
        显示名。
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[builtins.str]:
        """
        用户组id。
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="groupName")
    def group_name(self) -> pulumi.Output[builtins.str]:
        """
        用户组名称。
        """
        return pulumi.get(self, "group_name")

    @property
    @pulumi.getter(name="joinType")
    def join_type(self) -> pulumi.Output[builtins.str]:
        """
        用户组类型。
        """
        return pulumi.get(self, "join_type")

    @property
    @pulumi.getter
    def members(self) -> pulumi.Output[Sequence['outputs.GroupMember']]:
        return pulumi.get(self, "members")

    @property
    @pulumi.getter
    def source(self) -> pulumi.Output[builtins.str]:
        """
        用户组来源。
        """
        return pulumi.get(self, "source")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetVpnAttachmentResult',
    'AwaitableGetVpnAttachmentResult',
    'get_vpn_attachment',
    'get_vpn_attachment_output',
]

@pulumi.output_type
class GetVpnAttachmentResult:
    """
    A collection of values returned by getVpnAttachment.
    """
    def __init__(__self__, auto_publish_route_enabled=None, created_time=None, description=None, health_check_revoke_route_enabled=None, id=None, ipv6_enabled=None, status=None, tags=None, transit_router_attachment_id=None, transit_router_attachment_name=None, transit_router_id=None, transit_router_route_table_id=None, updated_time=None, vpn_connection_id=None, zone_id=None):
        if auto_publish_route_enabled and not isinstance(auto_publish_route_enabled, bool):
            raise TypeError("Expected argument 'auto_publish_route_enabled' to be a bool")
        pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if health_check_revoke_route_enabled and not isinstance(health_check_revoke_route_enabled, bool):
            raise TypeError("Expected argument 'health_check_revoke_route_enabled' to be a bool")
        pulumi.set(__self__, "health_check_revoke_route_enabled", health_check_revoke_route_enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ipv6_enabled and not isinstance(ipv6_enabled, bool):
            raise TypeError("Expected argument 'ipv6_enabled' to be a bool")
        pulumi.set(__self__, "ipv6_enabled", ipv6_enabled)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_id and not isinstance(transit_router_attachment_id, str):
            raise TypeError("Expected argument 'transit_router_attachment_id' to be a str")
        pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_attachment_name and not isinstance(transit_router_attachment_name, str):
            raise TypeError("Expected argument 'transit_router_attachment_name' to be a str")
        pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_id and not isinstance(transit_router_id, str):
            raise TypeError("Expected argument 'transit_router_id' to be a str")
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_route_table_id and not isinstance(transit_router_route_table_id, str):
            raise TypeError("Expected argument 'transit_router_route_table_id' to be a str")
        pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if vpn_connection_id and not isinstance(vpn_connection_id, str):
            raise TypeError("Expected argument 'vpn_connection_id' to be a str")
        pulumi.set(__self__, "vpn_connection_id", vpn_connection_id)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> builtins.bool:
        """
        是否自动同步TR路由到网络实例路由表中。
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthCheckRevokeRouteEnabled")
    def health_check_revoke_route_enabled(self) -> builtins.bool:
        """
        是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        """
        return pulumi.get(self, "health_check_revoke_route_enabled")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> builtins.bool:
        """
        是否开启IPv6功能。
        """
        return pulumi.get(self, "ipv6_enabled")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        网络实例连接的状态。Creating：创建中。Deleting：删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetVpnAttachmentTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> builtins.str:
        """
        网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> builtins.str:
        """
        网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> builtins.str:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> builtins.str:
        """
        关联的TR路由表ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpnConnectionId")
    def vpn_connection_id(self) -> builtins.str:
        """
        IPsec连接的ID。
        """
        return pulumi.get(self, "vpn_connection_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        IPsec连接所属可用区的ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetVpnAttachmentResult(GetVpnAttachmentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVpnAttachmentResult(
            auto_publish_route_enabled=self.auto_publish_route_enabled,
            created_time=self.created_time,
            description=self.description,
            health_check_revoke_route_enabled=self.health_check_revoke_route_enabled,
            id=self.id,
            ipv6_enabled=self.ipv6_enabled,
            status=self.status,
            tags=self.tags,
            transit_router_attachment_id=self.transit_router_attachment_id,
            transit_router_attachment_name=self.transit_router_attachment_name,
            transit_router_id=self.transit_router_id,
            transit_router_route_table_id=self.transit_router_route_table_id,
            updated_time=self.updated_time,
            vpn_connection_id=self.vpn_connection_id,
            zone_id=self.zone_id)


def get_vpn_attachment(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVpnAttachmentResult:
    """
    Data Source schema for Byteplus::TransitRouter::VpnAttachment


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:transitrouter/getVpnAttachment:getVpnAttachment', __args__, opts=opts, typ=GetVpnAttachmentResult).value

    return AwaitableGetVpnAttachmentResult(
        auto_publish_route_enabled=pulumi.get(__ret__, 'auto_publish_route_enabled'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        health_check_revoke_route_enabled=pulumi.get(__ret__, 'health_check_revoke_route_enabled'),
        id=pulumi.get(__ret__, 'id'),
        ipv6_enabled=pulumi.get(__ret__, 'ipv6_enabled'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        transit_router_attachment_id=pulumi.get(__ret__, 'transit_router_attachment_id'),
        transit_router_attachment_name=pulumi.get(__ret__, 'transit_router_attachment_name'),
        transit_router_id=pulumi.get(__ret__, 'transit_router_id'),
        transit_router_route_table_id=pulumi.get(__ret__, 'transit_router_route_table_id'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        vpn_connection_id=pulumi.get(__ret__, 'vpn_connection_id'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_vpn_attachment_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetVpnAttachmentResult]:
    """
    Data Source schema for Byteplus::TransitRouter::VpnAttachment


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:transitrouter/getVpnAttachment:getVpnAttachment', __args__, opts=opts, typ=GetVpnAttachmentResult)
    return __ret__.apply(lambda __response__: GetVpnAttachmentResult(
        auto_publish_route_enabled=pulumi.get(__response__, 'auto_publish_route_enabled'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        health_check_revoke_route_enabled=pulumi.get(__response__, 'health_check_revoke_route_enabled'),
        id=pulumi.get(__response__, 'id'),
        ipv6_enabled=pulumi.get(__response__, 'ipv6_enabled'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        transit_router_attachment_id=pulumi.get(__response__, 'transit_router_attachment_id'),
        transit_router_attachment_name=pulumi.get(__response__, 'transit_router_attachment_name'),
        transit_router_id=pulumi.get(__response__, 'transit_router_id'),
        transit_router_route_table_id=pulumi.get(__response__, 'transit_router_route_table_id'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        vpn_connection_id=pulumi.get(__response__, 'vpn_connection_id'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetAccesskeyResult',
    'AwaitableGetAccesskeyResult',
    'get_accesskey',
    'get_accesskey_output',
]

@pulumi.output_type
class GetAccesskeyResult:
    """
    A collection of values returned by getAccesskey.
    """
    def __init__(__self__, access_key_id=None, created_time=None, id=None, last_login_date=None, region=None, request_time=None, secret_access_key=None, service=None, status=None, updated_time=None, user_name=None):
        if access_key_id and not isinstance(access_key_id, str):
            raise TypeError("Expected argument 'access_key_id' to be a str")
        pulumi.set(__self__, "access_key_id", access_key_id)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_login_date and not isinstance(last_login_date, str):
            raise TypeError("Expected argument 'last_login_date' to be a str")
        pulumi.set(__self__, "last_login_date", last_login_date)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if request_time and not isinstance(request_time, str):
            raise TypeError("Expected argument 'request_time' to be a str")
        pulumi.set(__self__, "request_time", request_time)
        if secret_access_key and not isinstance(secret_access_key, str):
            raise TypeError("Expected argument 'secret_access_key' to be a str")
        pulumi.set(__self__, "secret_access_key", secret_access_key)
        if service and not isinstance(service, str):
            raise TypeError("Expected argument 'service' to be a str")
        pulumi.set(__self__, "service", service)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="accessKeyId")
    def access_key_id(self) -> builtins.str:
        """
        密钥ID（Access Key Id）。
        """
        return pulumi.get(self, "access_key_id")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        密钥创建时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="lastLoginDate")
    def last_login_date(self) -> builtins.str:
        """
        最后登录时间。
        """
        return pulumi.get(self, "last_login_date")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        API密钥最后访问的地域。
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="requestTime")
    def request_time(self) -> builtins.str:
        """
        API密钥的最后使用的时间。
        """
        return pulumi.get(self, "request_time")

    @property
    @pulumi.getter(name="secretAccessKey")
    def secret_access_key(self) -> builtins.str:
        """
        私有密钥（Secret Access Key）。
        """
        return pulumi.get(self, "secret_access_key")

    @property
    @pulumi.getter
    def service(self) -> builtins.str:
        """
        API密钥最后访问的服务的英文简称。
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        密钥状态。active代表启用状态，inactive代表禁用状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        密钥更新时间。时间格式为ISO8601。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> builtins.str:
        """
        用户名。用于给指定的IAM用户创建密钥，未指定用户名时则为当前请求身份创建密钥（即主账号请求时为主账号自身创建密钥，IAM用户请求时为IAM用户自身创建密钥。注意：角色不支持为自身创建密钥）。当IAM用户拥有密钥自管理权限时（AccessKeySelfManageAccess），如需为自身创建密钥则需要在请求中传递自身的UserName。
        """
        return pulumi.get(self, "user_name")


class AwaitableGetAccesskeyResult(GetAccesskeyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccesskeyResult(
            access_key_id=self.access_key_id,
            created_time=self.created_time,
            id=self.id,
            last_login_date=self.last_login_date,
            region=self.region,
            request_time=self.request_time,
            secret_access_key=self.secret_access_key,
            service=self.service,
            status=self.status,
            updated_time=self.updated_time,
            user_name=self.user_name)


def get_accesskey(id: Optional[builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccesskeyResult:
    """
    Data Source schema for Byteplus::IAM::AccessKey


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:iam/getAccesskey:getAccesskey', __args__, opts=opts, typ=GetAccesskeyResult).value

    return AwaitableGetAccesskeyResult(
        access_key_id=pulumi.get(__ret__, 'access_key_id'),
        created_time=pulumi.get(__ret__, 'created_time'),
        id=pulumi.get(__ret__, 'id'),
        last_login_date=pulumi.get(__ret__, 'last_login_date'),
        region=pulumi.get(__ret__, 'region'),
        request_time=pulumi.get(__ret__, 'request_time'),
        secret_access_key=pulumi.get(__ret__, 'secret_access_key'),
        service=pulumi.get(__ret__, 'service'),
        status=pulumi.get(__ret__, 'status'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        user_name=pulumi.get(__ret__, 'user_name'))
def get_accesskey_output(id: Optional[pulumi.Input[builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccesskeyResult]:
    """
    Data Source schema for Byteplus::IAM::AccessKey


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:iam/getAccesskey:getAccesskey', __args__, opts=opts, typ=GetAccesskeyResult)
    return __ret__.apply(lambda __response__: GetAccesskeyResult(
        access_key_id=pulumi.get(__response__, 'access_key_id'),
        created_time=pulumi.get(__response__, 'created_time'),
        id=pulumi.get(__response__, 'id'),
        last_login_date=pulumi.get(__response__, 'last_login_date'),
        region=pulumi.get(__response__, 'region'),
        request_time=pulumi.get(__response__, 'request_time'),
        secret_access_key=pulumi.get(__response__, 'secret_access_key'),
        service=pulumi.get(__response__, 'service'),
        status=pulumi.get(__response__, 'status'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        user_name=pulumi.get(__response__, 'user_name')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccountArgs', 'Account']

@pulumi.input_type
class AccountArgs:
    def __init__(__self__, *,
                 account_name: pulumi.Input[builtins.str],
                 instance_id: pulumi.Input[builtins.str],
                 password: pulumi.Input[builtins.str],
                 role_name: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Account resource.
        :param pulumi.Input[builtins.str] account_name: 账号名称。名称需同时满足如下要求：以小写字母开头，由小写字母或者数字结尾。长度为 2~16 个字符。由小写字母、数字、下划线（_）组成。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] password: 账号密码。密码需同时满足如下要求：长度为 8~32 个字符。至少包含大写字母、小写字母、数字或特殊字符中的任意 2 种。支持如下特殊字符：()`~!@#$%^&*-+=_|{}[];<>,.?
        :param pulumi.Input[builtins.str] role_name: 账号所属角色。支持如下默认角色：Administrator：允许对所有 Key 使用所有 Redis 实例已支持的命令。ReadWrite：允许对所有 Key 使用除 admin 类之外的所有命令。ReadOnly：允许对所有 Key 使用 read 类中的所有命令。NotDangerous：允许对所有 Key 使用除 dangerous 类之外的所有命令。说明关于各角色对应 ACL 规则支持的具体命令详情，请参见 ACL 语法。
        :param pulumi.Input[builtins.str] description: 账号描述，长度不超过 256 个字符。说明若该参数为空，表示不设置账号描述。
        """
        pulumi.set(__self__, "account_name", account_name)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "password", password)
        pulumi.set(__self__, "role_name", role_name)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Input[builtins.str]:
        """
        账号名称。名称需同时满足如下要求：以小写字母开头，由小写字母或者数字结尾。长度为 2~16 个字符。由小写字母、数字、下划线（_）组成。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def password(self) -> pulumi.Input[builtins.str]:
        """
        账号密码。密码需同时满足如下要求：长度为 8~32 个字符。至少包含大写字母、小写字母、数字或特殊字符中的任意 2 种。支持如下特殊字符：()`~!@#$%^&*-+=_|{}[];<>,.?
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[builtins.str]:
        """
        账号所属角色。支持如下默认角色：Administrator：允许对所有 Key 使用所有 Redis 实例已支持的命令。ReadWrite：允许对所有 Key 使用除 admin 类之外的所有命令。ReadOnly：允许对所有 Key 使用 read 类中的所有命令。NotDangerous：允许对所有 Key 使用除 dangerous 类之外的所有命令。说明关于各角色对应 ACL 规则支持的具体命令详情，请参见 ACL 语法。
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号描述，长度不超过 256 个字符。说明若该参数为空，表示不设置账号描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _AccountState:
    def __init__(__self__, *,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 account_status: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Account resources.
        :param pulumi.Input[builtins.str] account_name: 账号名称。名称需同时满足如下要求：以小写字母开头，由小写字母或者数字结尾。长度为 2~16 个字符。由小写字母、数字、下划线（_）组成。
        :param pulumi.Input[builtins.str] account_status: 账号状态。取值范围如下：Available：可用。Unavailable：不可用。
        :param pulumi.Input[builtins.str] description: 账号描述，长度不超过 256 个字符。说明若该参数为空，表示不设置账号描述。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] password: 账号密码。密码需同时满足如下要求：长度为 8~32 个字符。至少包含大写字母、小写字母、数字或特殊字符中的任意 2 种。支持如下特殊字符：()`~!@#$%^&*-+=_|{}[];<>,.?
        :param pulumi.Input[builtins.str] role_name: 账号所属角色。支持如下默认角色：Administrator：允许对所有 Key 使用所有 Redis 实例已支持的命令。ReadWrite：允许对所有 Key 使用除 admin 类之外的所有命令。ReadOnly：允许对所有 Key 使用 read 类中的所有命令。NotDangerous：允许对所有 Key 使用除 dangerous 类之外的所有命令。说明关于各角色对应 ACL 规则支持的具体命令详情，请参见 ACL 语法。
        """
        if account_name is not None:
            pulumi.set(__self__, "account_name", account_name)
        if account_status is not None:
            pulumi.set(__self__, "account_status", account_status)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号名称。名称需同时满足如下要求：以小写字母开头，由小写字母或者数字结尾。长度为 2~16 个字符。由小写字母、数字、下划线（_）组成。
        """
        return pulumi.get(self, "account_name")

    @account_name.setter
    def account_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_name", value)

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号状态。取值范围如下：Available：可用。Unavailable：不可用。
        """
        return pulumi.get(self, "account_status")

    @account_status.setter
    def account_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "account_status", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号描述，长度不超过 256 个字符。说明若该参数为空，表示不设置账号描述。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号密码。密码需同时满足如下要求：长度为 8~32 个字符。至少包含大写字母、小写字母、数字或特殊字符中的任意 2 种。支持如下特殊字符：()`~!@#$%^&*-+=_|{}[];<>,.?
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        账号所属角色。支持如下默认角色：Administrator：允许对所有 Key 使用所有 Redis 实例已支持的命令。ReadWrite：允许对所有 Key 使用除 admin 类之外的所有命令。ReadOnly：允许对所有 Key 使用 read 类中的所有命令。NotDangerous：允许对所有 Key 使用除 dangerous 类之外的所有命令。说明关于各角色对应 ACL 规则支持的具体命令详情，请参见 ACL 语法。
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_name", value)


@pulumi.type_token("bytepluscc:redis/account:Account")
class Account(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        缓存数据库 Redis 版支持创建多个账号，您可以在创建账号时选择不同的角色，不同的角色支持的权限不同，帮助您实现数据库的精细化管理，提升数据安全性。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        redis_account_demo = bytepluscc.redis.Account("RedisAccountDemo",
            instance_id="redis-mlrfiqivjttxxxxx",
            account_name="ccapi_test_1",
            description="this is a test",
            password="******",
            role_name="Administrator")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:redis/account:Account example "instance_id|account_name"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_name: 账号名称。名称需同时满足如下要求：以小写字母开头，由小写字母或者数字结尾。长度为 2~16 个字符。由小写字母、数字、下划线（_）组成。
        :param pulumi.Input[builtins.str] description: 账号描述，长度不超过 256 个字符。说明若该参数为空，表示不设置账号描述。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] password: 账号密码。密码需同时满足如下要求：长度为 8~32 个字符。至少包含大写字母、小写字母、数字或特殊字符中的任意 2 种。支持如下特殊字符：()`~!@#$%^&*-+=_|{}[];<>,.?
        :param pulumi.Input[builtins.str] role_name: 账号所属角色。支持如下默认角色：Administrator：允许对所有 Key 使用所有 Redis 实例已支持的命令。ReadWrite：允许对所有 Key 使用除 admin 类之外的所有命令。ReadOnly：允许对所有 Key 使用 read 类中的所有命令。NotDangerous：允许对所有 Key 使用除 dangerous 类之外的所有命令。说明关于各角色对应 ACL 规则支持的具体命令详情，请参见 ACL 语法。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AccountArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        缓存数据库 Redis 版支持创建多个账号，您可以在创建账号时选择不同的角色，不同的角色支持的权限不同，帮助您实现数据库的精细化管理，提升数据安全性。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        redis_account_demo = bytepluscc.redis.Account("RedisAccountDemo",
            instance_id="redis-mlrfiqivjttxxxxx",
            account_name="ccapi_test_1",
            description="this is a test",
            password="******",
            role_name="Administrator")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:redis/account:Account example "instance_id|account_name"
        ```

        :param str resource_name: The name of the resource.
        :param AccountArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccountArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_name: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 role_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccountArgs.__new__(AccountArgs)

            if account_name is None and not opts.urn:
                raise TypeError("Missing required property 'account_name'")
            __props__.__dict__["account_name"] = account_name
            __props__.__dict__["description"] = description
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            if password is None and not opts.urn:
                raise TypeError("Missing required property 'password'")
            __props__.__dict__["password"] = password
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
            __props__.__dict__["account_status"] = None
        super(Account, __self__).__init__(
            'bytepluscc:redis/account:Account',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_name: Optional[pulumi.Input[builtins.str]] = None,
            account_status: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            role_name: Optional[pulumi.Input[builtins.str]] = None) -> 'Account':
        """
        Get an existing Account resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] account_name: 账号名称。名称需同时满足如下要求：以小写字母开头，由小写字母或者数字结尾。长度为 2~16 个字符。由小写字母、数字、下划线（_）组成。
        :param pulumi.Input[builtins.str] account_status: 账号状态。取值范围如下：Available：可用。Unavailable：不可用。
        :param pulumi.Input[builtins.str] description: 账号描述，长度不超过 256 个字符。说明若该参数为空，表示不设置账号描述。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] password: 账号密码。密码需同时满足如下要求：长度为 8~32 个字符。至少包含大写字母、小写字母、数字或特殊字符中的任意 2 种。支持如下特殊字符：()`~!@#$%^&*-+=_|{}[];<>,.?
        :param pulumi.Input[builtins.str] role_name: 账号所属角色。支持如下默认角色：Administrator：允许对所有 Key 使用所有 Redis 实例已支持的命令。ReadWrite：允许对所有 Key 使用除 admin 类之外的所有命令。ReadOnly：允许对所有 Key 使用 read 类中的所有命令。NotDangerous：允许对所有 Key 使用除 dangerous 类之外的所有命令。说明关于各角色对应 ACL 规则支持的具体命令详情，请参见 ACL 语法。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccountState.__new__(_AccountState)

        __props__.__dict__["account_name"] = account_name
        __props__.__dict__["account_status"] = account_status
        __props__.__dict__["description"] = description
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["password"] = password
        __props__.__dict__["role_name"] = role_name
        return Account(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="accountName")
    def account_name(self) -> pulumi.Output[builtins.str]:
        """
        账号名称。名称需同时满足如下要求：以小写字母开头，由小写字母或者数字结尾。长度为 2~16 个字符。由小写字母、数字、下划线（_）组成。
        """
        return pulumi.get(self, "account_name")

    @property
    @pulumi.getter(name="accountStatus")
    def account_status(self) -> pulumi.Output[builtins.str]:
        """
        账号状态。取值范围如下：Available：可用。Unavailable：不可用。
        """
        return pulumi.get(self, "account_status")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        账号描述，长度不超过 256 个字符。说明若该参数为空，表示不设置账号描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        账号密码。密码需同时满足如下要求：长度为 8~32 个字符。至少包含大写字母、小写字母、数字或特殊字符中的任意 2 种。支持如下特殊字符：()`~!@#$%^&*-+=_|{}[];<>,.?
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[builtins.str]:
        """
        账号所属角色。支持如下默认角色：Administrator：允许对所有 Key 使用所有 Redis 实例已支持的命令。ReadWrite：允许对所有 Key 使用除 admin 类之外的所有命令。ReadOnly：允许对所有 Key 使用 read 类中的所有命令。NotDangerous：允许对所有 Key 使用除 dangerous 类之外的所有命令。说明关于各角色对应 ACL 规则支持的具体命令详情，请参见 ACL 语法。
        """
        return pulumi.get(self, "role_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetIpv6AddressBandwidthResult',
    'AwaitableGetIpv6AddressBandwidthResult',
    'get_ipv6_address_bandwidth',
    'get_ipv6_address_bandwidth_output',
]

@pulumi.output_type
class GetIpv6AddressBandwidthResult:
    """
    A collection of values returned by getIpv6AddressBandwidth.
    """
    def __init__(__self__, allocation_id=None, bandwidth=None, bandwidth_package_id=None, billing_type=None, business_status=None, created_time=None, deleted_time=None, id=None, instance_id=None, instance_type=None, ipv6_address=None, ipv6_gateway_id=None, isp=None, lock_reason=None, network_type=None, overdue_time=None, project_name=None, service_managed=None, status=None, tags=None, updated_time=None):
        if allocation_id and not isinstance(allocation_id, str):
            raise TypeError("Expected argument 'allocation_id' to be a str")
        pulumi.set(__self__, "allocation_id", allocation_id)
        if bandwidth and not isinstance(bandwidth, int):
            raise TypeError("Expected argument 'bandwidth' to be a int")
        pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_id and not isinstance(bandwidth_package_id, str):
            raise TypeError("Expected argument 'bandwidth_package_id' to be a str")
        pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if billing_type and not isinstance(billing_type, int):
            raise TypeError("Expected argument 'billing_type' to be a int")
        pulumi.set(__self__, "billing_type", billing_type)
        if business_status and not isinstance(business_status, str):
            raise TypeError("Expected argument 'business_status' to be a str")
        pulumi.set(__self__, "business_status", business_status)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if deleted_time and not isinstance(deleted_time, str):
            raise TypeError("Expected argument 'deleted_time' to be a str")
        pulumi.set(__self__, "deleted_time", deleted_time)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if ipv6_address and not isinstance(ipv6_address, str):
            raise TypeError("Expected argument 'ipv6_address' to be a str")
        pulumi.set(__self__, "ipv6_address", ipv6_address)
        if ipv6_gateway_id and not isinstance(ipv6_gateway_id, str):
            raise TypeError("Expected argument 'ipv6_gateway_id' to be a str")
        pulumi.set(__self__, "ipv6_gateway_id", ipv6_gateway_id)
        if isp and not isinstance(isp, str):
            raise TypeError("Expected argument 'isp' to be a str")
        pulumi.set(__self__, "isp", isp)
        if lock_reason and not isinstance(lock_reason, str):
            raise TypeError("Expected argument 'lock_reason' to be a str")
        pulumi.set(__self__, "lock_reason", lock_reason)
        if network_type and not isinstance(network_type, str):
            raise TypeError("Expected argument 'network_type' to be a str")
        pulumi.set(__self__, "network_type", network_type)
        if overdue_time and not isinstance(overdue_time, str):
            raise TypeError("Expected argument 'overdue_time' to be a str")
        pulumi.set(__self__, "overdue_time", overdue_time)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if service_managed and not isinstance(service_managed, bool):
            raise TypeError("Expected argument 'service_managed' to be a bool")
        pulumi.set(__self__, "service_managed", service_managed)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> builtins.str:
        """
        IPv6公网带宽的ID。
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.int:
        """
        IPv6公网带宽的带宽上限。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> builtins.str:
        """
        IPv6共享带宽包的ID。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.int:
        """
        IPv6公网带宽的计费类型。2：按量计费-按带宽上限计费。3：按量计费-按实际流量计费。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> builtins.str:
        """
        IPv6公网带宽是否被锁定。Normal：正常。FinancialLocked：被锁定。
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        IPv6公网带宽的开通时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> builtins.str:
        """
        IPv6公网带宽的删除时间。
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        IPv6公网带宽关联的实例ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        IPv6公网带宽关联的实例类型。EcsInstance：云服务器实例。ClbInstance：负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="ipv6Address")
    def ipv6_address(self) -> builtins.str:
        """
        IPv6地址。
        """
        return pulumi.get(self, "ipv6_address")

    @property
    @pulumi.getter(name="ipv6GatewayId")
    def ipv6_gateway_id(self) -> builtins.str:
        """
        IPv6网关的ID。
        """
        return pulumi.get(self, "ipv6_gateway_id")

    @property
    @pulumi.getter
    def isp(self) -> builtins.str:
        """
        IPv6公网带宽的线路类型。BGP：BGP（多线）。
        """
        return pulumi.get(self, "isp")

    @property
    @pulumi.getter(name="lockReason")
    def lock_reason(self) -> builtins.str:
        """
        IPv6公网带宽被锁定的原因。该参数只有IPv6公网带宽处于FinancialLocked状态时才有返回值。Financial：因欠费被锁定。Security：因安全被锁定。
        """
        return pulumi.get(self, "lock_reason")

    @property
    @pulumi.getter(name="networkType")
    def network_type(self) -> builtins.str:
        """
        IPv6地址的通信类型。Private：私网通信类型。Public：公网通信类型。
        """
        return pulumi.get(self, "network_type")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> builtins.str:
        """
        IPv6公网带宽欠费关停的时间。
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        IPv6公网带宽的项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="serviceManaged")
    def service_managed(self) -> builtins.bool:
        """
        是否为服务托管。
        """
        return pulumi.get(self, "service_managed")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        IPv6公网带宽的状态。Creating：创建中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetIpv6AddressBandwidthTagResult']:
        """
        标签信息
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        IPv6公网带宽的最近操作时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetIpv6AddressBandwidthResult(GetIpv6AddressBandwidthResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIpv6AddressBandwidthResult(
            allocation_id=self.allocation_id,
            bandwidth=self.bandwidth,
            bandwidth_package_id=self.bandwidth_package_id,
            billing_type=self.billing_type,
            business_status=self.business_status,
            created_time=self.created_time,
            deleted_time=self.deleted_time,
            id=self.id,
            instance_id=self.instance_id,
            instance_type=self.instance_type,
            ipv6_address=self.ipv6_address,
            ipv6_gateway_id=self.ipv6_gateway_id,
            isp=self.isp,
            lock_reason=self.lock_reason,
            network_type=self.network_type,
            overdue_time=self.overdue_time,
            project_name=self.project_name,
            service_managed=self.service_managed,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_ipv6_address_bandwidth(id: Optional[builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIpv6AddressBandwidthResult:
    """
    Data Source schema for Byteplus::VPC::Ipv6AddressBandwidth


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getIpv6AddressBandwidth:getIpv6AddressBandwidth', __args__, opts=opts, typ=GetIpv6AddressBandwidthResult).value

    return AwaitableGetIpv6AddressBandwidthResult(
        allocation_id=pulumi.get(__ret__, 'allocation_id'),
        bandwidth=pulumi.get(__ret__, 'bandwidth'),
        bandwidth_package_id=pulumi.get(__ret__, 'bandwidth_package_id'),
        billing_type=pulumi.get(__ret__, 'billing_type'),
        business_status=pulumi.get(__ret__, 'business_status'),
        created_time=pulumi.get(__ret__, 'created_time'),
        deleted_time=pulumi.get(__ret__, 'deleted_time'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        ipv6_address=pulumi.get(__ret__, 'ipv6_address'),
        ipv6_gateway_id=pulumi.get(__ret__, 'ipv6_gateway_id'),
        isp=pulumi.get(__ret__, 'isp'),
        lock_reason=pulumi.get(__ret__, 'lock_reason'),
        network_type=pulumi.get(__ret__, 'network_type'),
        overdue_time=pulumi.get(__ret__, 'overdue_time'),
        project_name=pulumi.get(__ret__, 'project_name'),
        service_managed=pulumi.get(__ret__, 'service_managed'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_ipv6_address_bandwidth_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIpv6AddressBandwidthResult]:
    """
    Data Source schema for Byteplus::VPC::Ipv6AddressBandwidth


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getIpv6AddressBandwidth:getIpv6AddressBandwidth', __args__, opts=opts, typ=GetIpv6AddressBandwidthResult)
    return __ret__.apply(lambda __response__: GetIpv6AddressBandwidthResult(
        allocation_id=pulumi.get(__response__, 'allocation_id'),
        bandwidth=pulumi.get(__response__, 'bandwidth'),
        bandwidth_package_id=pulumi.get(__response__, 'bandwidth_package_id'),
        billing_type=pulumi.get(__response__, 'billing_type'),
        business_status=pulumi.get(__response__, 'business_status'),
        created_time=pulumi.get(__response__, 'created_time'),
        deleted_time=pulumi.get(__response__, 'deleted_time'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        ipv6_address=pulumi.get(__response__, 'ipv6_address'),
        ipv6_gateway_id=pulumi.get(__response__, 'ipv6_gateway_id'),
        isp=pulumi.get(__response__, 'isp'),
        lock_reason=pulumi.get(__response__, 'lock_reason'),
        network_type=pulumi.get(__response__, 'network_type'),
        overdue_time=pulumi.get(__response__, 'overdue_time'),
        project_name=pulumi.get(__response__, 'project_name'),
        service_managed=pulumi.get(__response__, 'service_managed'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GroupMemberArgs',
    'GroupMemberArgsDict',
    'PermissionSetPermissionPolicyArgs',
    'PermissionSetPermissionPolicyArgsDict',
]

MYPY = False

if not MYPY:
    class GroupMemberArgsDict(TypedDict):
        user_id: NotRequired[pulumi.Input[builtins.str]]
        """
        用户id。
        """
elif False:
    GroupMemberArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class GroupMemberArgs:
    def __init__(__self__, *,
                 user_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] user_id: 用户id。
        """
        if user_id is not None:
            pulumi.set(__self__, "user_id", user_id)

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        用户id。
        """
        return pulumi.get(self, "user_id")

    @user_id.setter
    def user_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "user_id", value)


if not MYPY:
    class PermissionSetPermissionPolicyArgsDict(TypedDict):
        permission_policy_document: NotRequired[pulumi.Input[builtins.str]]
        """
        策略语法内容。语法可参考 策略语法说明。
        """
        permission_policy_name: NotRequired[pulumi.Input[builtins.str]]
        """
        策略名称。
        """
        permission_policy_type: NotRequired[pulumi.Input[builtins.str]]
        """
        策略类型，System or Inline。
        """
elif False:
    PermissionSetPermissionPolicyArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class PermissionSetPermissionPolicyArgs:
    def __init__(__self__, *,
                 permission_policy_document: Optional[pulumi.Input[builtins.str]] = None,
                 permission_policy_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_policy_type: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] permission_policy_document: 策略语法内容。语法可参考 策略语法说明。
        :param pulumi.Input[builtins.str] permission_policy_name: 策略名称。
        :param pulumi.Input[builtins.str] permission_policy_type: 策略类型，System or Inline。
        """
        if permission_policy_document is not None:
            pulumi.set(__self__, "permission_policy_document", permission_policy_document)
        if permission_policy_name is not None:
            pulumi.set(__self__, "permission_policy_name", permission_policy_name)
        if permission_policy_type is not None:
            pulumi.set(__self__, "permission_policy_type", permission_policy_type)

    @property
    @pulumi.getter(name="permissionPolicyDocument")
    def permission_policy_document(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略语法内容。语法可参考 策略语法说明。
        """
        return pulumi.get(self, "permission_policy_document")

    @permission_policy_document.setter
    def permission_policy_document(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_policy_document", value)

    @property
    @pulumi.getter(name="permissionPolicyName")
    def permission_policy_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略名称。
        """
        return pulumi.get(self, "permission_policy_name")

    @permission_policy_name.setter
    def permission_policy_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_policy_name", value)

    @property
    @pulumi.getter(name="permissionPolicyType")
    def permission_policy_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        策略类型，System or Inline。
        """
        return pulumi.get(self, "permission_policy_type")

    @permission_policy_type.setter
    def permission_policy_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_policy_type", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLaunchTemplateVersionResult',
    'AwaitableGetLaunchTemplateVersionResult',
    'get_launch_template_version',
    'get_launch_template_version_output',
]

@pulumi.output_type
class GetLaunchTemplateVersionResult:
    """
    A collection of values returned by getLaunchTemplateVersion.
    """
    def __init__(__self__, deployment_set_group_number=None, deployment_set_id=None, description=None, eip=None, host_name=None, hpc_cluster_id=None, id=None, image_id=None, image_name=None, instance_charge_type=None, instance_name=None, instance_type_id=None, keep_image_credential=None, key_pair_name=None, launch_template_id=None, network_interfaces=None, project_name=None, scheduled_instance=None, security_enhancement_strategy=None, spot_price_limit=None, spot_strategy=None, suffix_index=None, tags=None, unique_suffix=None, user_data=None, version_description=None, version_number=None, volumes=None, vpc_id=None, zone_id=None):
        if deployment_set_group_number and not isinstance(deployment_set_group_number, int):
            raise TypeError("Expected argument 'deployment_set_group_number' to be a int")
        pulumi.set(__self__, "deployment_set_group_number", deployment_set_group_number)
        if deployment_set_id and not isinstance(deployment_set_id, str):
            raise TypeError("Expected argument 'deployment_set_id' to be a str")
        pulumi.set(__self__, "deployment_set_id", deployment_set_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if eip and not isinstance(eip, dict):
            raise TypeError("Expected argument 'eip' to be a dict")
        pulumi.set(__self__, "eip", eip)
        if host_name and not isinstance(host_name, str):
            raise TypeError("Expected argument 'host_name' to be a str")
        pulumi.set(__self__, "host_name", host_name)
        if hpc_cluster_id and not isinstance(hpc_cluster_id, str):
            raise TypeError("Expected argument 'hpc_cluster_id' to be a str")
        pulumi.set(__self__, "hpc_cluster_id", hpc_cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_id and not isinstance(image_id, str):
            raise TypeError("Expected argument 'image_id' to be a str")
        pulumi.set(__self__, "image_id", image_id)
        if image_name and not isinstance(image_name, str):
            raise TypeError("Expected argument 'image_name' to be a str")
        pulumi.set(__self__, "image_name", image_name)
        if instance_charge_type and not isinstance(instance_charge_type, str):
            raise TypeError("Expected argument 'instance_charge_type' to be a str")
        pulumi.set(__self__, "instance_charge_type", instance_charge_type)
        if instance_name and not isinstance(instance_name, str):
            raise TypeError("Expected argument 'instance_name' to be a str")
        pulumi.set(__self__, "instance_name", instance_name)
        if instance_type_id and not isinstance(instance_type_id, str):
            raise TypeError("Expected argument 'instance_type_id' to be a str")
        pulumi.set(__self__, "instance_type_id", instance_type_id)
        if keep_image_credential and not isinstance(keep_image_credential, bool):
            raise TypeError("Expected argument 'keep_image_credential' to be a bool")
        pulumi.set(__self__, "keep_image_credential", keep_image_credential)
        if key_pair_name and not isinstance(key_pair_name, str):
            raise TypeError("Expected argument 'key_pair_name' to be a str")
        pulumi.set(__self__, "key_pair_name", key_pair_name)
        if launch_template_id and not isinstance(launch_template_id, str):
            raise TypeError("Expected argument 'launch_template_id' to be a str")
        pulumi.set(__self__, "launch_template_id", launch_template_id)
        if network_interfaces and not isinstance(network_interfaces, list):
            raise TypeError("Expected argument 'network_interfaces' to be a list")
        pulumi.set(__self__, "network_interfaces", network_interfaces)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if scheduled_instance and not isinstance(scheduled_instance, dict):
            raise TypeError("Expected argument 'scheduled_instance' to be a dict")
        pulumi.set(__self__, "scheduled_instance", scheduled_instance)
        if security_enhancement_strategy and not isinstance(security_enhancement_strategy, str):
            raise TypeError("Expected argument 'security_enhancement_strategy' to be a str")
        pulumi.set(__self__, "security_enhancement_strategy", security_enhancement_strategy)
        if spot_price_limit and not isinstance(spot_price_limit, float):
            raise TypeError("Expected argument 'spot_price_limit' to be a float")
        pulumi.set(__self__, "spot_price_limit", spot_price_limit)
        if spot_strategy and not isinstance(spot_strategy, str):
            raise TypeError("Expected argument 'spot_strategy' to be a str")
        pulumi.set(__self__, "spot_strategy", spot_strategy)
        if suffix_index and not isinstance(suffix_index, int):
            raise TypeError("Expected argument 'suffix_index' to be a int")
        pulumi.set(__self__, "suffix_index", suffix_index)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if unique_suffix and not isinstance(unique_suffix, bool):
            raise TypeError("Expected argument 'unique_suffix' to be a bool")
        pulumi.set(__self__, "unique_suffix", unique_suffix)
        if user_data and not isinstance(user_data, str):
            raise TypeError("Expected argument 'user_data' to be a str")
        pulumi.set(__self__, "user_data", user_data)
        if version_description and not isinstance(version_description, str):
            raise TypeError("Expected argument 'version_description' to be a str")
        pulumi.set(__self__, "version_description", version_description)
        if version_number and not isinstance(version_number, str):
            raise TypeError("Expected argument 'version_number' to be a str")
        pulumi.set(__self__, "version_number", version_number)
        if volumes and not isinstance(volumes, list):
            raise TypeError("Expected argument 'volumes' to be a list")
        pulumi.set(__self__, "volumes", volumes)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="deploymentSetGroupNumber")
    def deployment_set_group_number(self) -> builtins.int:
        """
        当ECS实例要加入或调整的部署集策略为部署集组高可用策略（AvailabilityGroup）时，可以通过该参数指定实例在部署集中的分组号。
        """
        return pulumi.get(self, "deployment_set_group_number")

    @property
    @pulumi.getter(name="deploymentSetId")
    def deployment_set_id(self) -> builtins.str:
        """
        实例需要加入的部署集ID。
        """
        return pulumi.get(self, "deployment_set_id")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        实例的描述。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def eip(self) -> 'outputs.GetLaunchTemplateVersionEipResult':
        """
        实例绑定的公网IP信息。
        """
        return pulumi.get(self, "eip")

    @property
    @pulumi.getter(name="hostName")
    def host_name(self) -> builtins.str:
        """
        实例的主机名。Linux系统的主机名长度限制为2～59个字符。Windows系统的主机名长度限制为2～10个字符。
        """
        return pulumi.get(self, "host_name")

    @property
    @pulumi.getter(name="hpcClusterId")
    def hpc_cluster_id(self) -> builtins.str:
        """
        当创建高性能计算GPU型实例时，请指定高性能计算集群ID。
        """
        return pulumi.get(self, "hpc_cluster_id")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> builtins.str:
        """
        镜像ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="imageName")
    def image_name(self) -> builtins.str:
        """
        镜像名称。
        """
        return pulumi.get(self, "image_name")

    @property
    @pulumi.getter(name="instanceChargeType")
    def instance_charge_type(self) -> builtins.str:
        """
        实例和云盘的计费类型，取值：PostPaid：按量计费。PrePaid：包年包月。Esi：弹性预约实例。Segmented：时段型弹性预约实例。
        """
        return pulumi.get(self, "instance_charge_type")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> builtins.str:
        """
        实例的名称。
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceTypeId")
    def instance_type_id(self) -> builtins.str:
        """
        实例的规格。
        """
        return pulumi.get(self, "instance_type_id")

    @property
    @pulumi.getter(name="keepImageCredential")
    def keep_image_credential(self) -> builtins.bool:
        """
        是否保留镜像设置，取值：true：保留镜像设置，保留后将使用镜像预设的密码或密钥对登录实例。false（默认）：不保留镜像设置。
        """
        return pulumi.get(self, "keep_image_credential")

    @property
    @pulumi.getter(name="keyPairName")
    def key_pair_name(self) -> builtins.str:
        """
        实例绑定的密钥对。
        """
        return pulumi.get(self, "key_pair_name")

    @property
    @pulumi.getter(name="launchTemplateId")
    def launch_template_id(self) -> builtins.str:
        """
        实例启动模板 ID。
        """
        return pulumi.get(self, "launch_template_id")

    @property
    @pulumi.getter(name="networkInterfaces")
    def network_interfaces(self) -> Sequence['outputs.GetLaunchTemplateVersionNetworkInterfaceResult']:
        """
        实例挂载的网卡信息。
        """
        return pulumi.get(self, "network_interfaces")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        实例所属项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="scheduledInstance")
    def scheduled_instance(self) -> 'outputs.GetLaunchTemplateVersionScheduledInstanceResult':
        """
        弹性预约单信息。
        """
        return pulumi.get(self, "scheduled_instance")

    @property
    @pulumi.getter(name="securityEnhancementStrategy")
    def security_enhancement_strategy(self) -> builtins.str:
        """
        是否开启安全加固。Active:开启安全加固，仅对公共镜像生效。InActive:关闭安全加固，对所有镜像生效。
        """
        return pulumi.get(self, "security_enhancement_strategy")

    @property
    @pulumi.getter(name="spotPriceLimit")
    def spot_price_limit(self) -> builtins.float:
        """
        抢占式实例的每小时最高价格。
        """
        return pulumi.get(self, "spot_price_limit")

    @property
    @pulumi.getter(name="spotStrategy")
    def spot_strategy(self) -> builtins.str:
        """
        按量计费的抢占式策略。取值：NoSpot：表示创建正常按量计费实例。SpotAsPriceGo：系统自动出价，跟随当前市场实际价格的抢占式实例。SpotWithPriceLimit：设置出价上限的抢占式实例。
        """
        return pulumi.get(self, "spot_strategy")

    @property
    @pulumi.getter(name="suffixIndex")
    def suffix_index(self) -> builtins.int:
        """
        有序后缀的起始序号。
        """
        return pulumi.get(self, "suffix_index")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetLaunchTemplateVersionTagResult']:
        """
        实例的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="uniqueSuffix")
    def unique_suffix(self) -> builtins.bool:
        """
        表示当创建多台实例时，是否为Hostname和InstanceName自动添加有序后缀。
        """
        return pulumi.get(self, "unique_suffix")

    @property
    @pulumi.getter(name="userData")
    def user_data(self) -> builtins.str:
        """
        实例的自定义数据。
        """
        return pulumi.get(self, "user_data")

    @property
    @pulumi.getter(name="versionDescription")
    def version_description(self) -> builtins.str:
        """
        模版版本描述。
        """
        return pulumi.get(self, "version_description")

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> builtins.str:
        """
        模板版本号。
        """
        return pulumi.get(self, "version_number")

    @property
    @pulumi.getter
    def volumes(self) -> Sequence['outputs.GetLaunchTemplateVersionVolumeResult']:
        """
        实例绑定的云盘信息。
        """
        return pulumi.get(self, "volumes")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> builtins.str:
        """
        私有网络ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> builtins.str:
        """
        实例所属可用区ID。
        """
        return pulumi.get(self, "zone_id")


class AwaitableGetLaunchTemplateVersionResult(GetLaunchTemplateVersionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLaunchTemplateVersionResult(
            deployment_set_group_number=self.deployment_set_group_number,
            deployment_set_id=self.deployment_set_id,
            description=self.description,
            eip=self.eip,
            host_name=self.host_name,
            hpc_cluster_id=self.hpc_cluster_id,
            id=self.id,
            image_id=self.image_id,
            image_name=self.image_name,
            instance_charge_type=self.instance_charge_type,
            instance_name=self.instance_name,
            instance_type_id=self.instance_type_id,
            keep_image_credential=self.keep_image_credential,
            key_pair_name=self.key_pair_name,
            launch_template_id=self.launch_template_id,
            network_interfaces=self.network_interfaces,
            project_name=self.project_name,
            scheduled_instance=self.scheduled_instance,
            security_enhancement_strategy=self.security_enhancement_strategy,
            spot_price_limit=self.spot_price_limit,
            spot_strategy=self.spot_strategy,
            suffix_index=self.suffix_index,
            tags=self.tags,
            unique_suffix=self.unique_suffix,
            user_data=self.user_data,
            version_description=self.version_description,
            version_number=self.version_number,
            volumes=self.volumes,
            vpc_id=self.vpc_id,
            zone_id=self.zone_id)


def get_launch_template_version(id: Optional[builtins.str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLaunchTemplateVersionResult:
    """
    Data Source schema for Byteplus::ECS::LaunchtemplateVersion


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:ecs/getLaunchTemplateVersion:getLaunchTemplateVersion', __args__, opts=opts, typ=GetLaunchTemplateVersionResult).value

    return AwaitableGetLaunchTemplateVersionResult(
        deployment_set_group_number=pulumi.get(__ret__, 'deployment_set_group_number'),
        deployment_set_id=pulumi.get(__ret__, 'deployment_set_id'),
        description=pulumi.get(__ret__, 'description'),
        eip=pulumi.get(__ret__, 'eip'),
        host_name=pulumi.get(__ret__, 'host_name'),
        hpc_cluster_id=pulumi.get(__ret__, 'hpc_cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        image_id=pulumi.get(__ret__, 'image_id'),
        image_name=pulumi.get(__ret__, 'image_name'),
        instance_charge_type=pulumi.get(__ret__, 'instance_charge_type'),
        instance_name=pulumi.get(__ret__, 'instance_name'),
        instance_type_id=pulumi.get(__ret__, 'instance_type_id'),
        keep_image_credential=pulumi.get(__ret__, 'keep_image_credential'),
        key_pair_name=pulumi.get(__ret__, 'key_pair_name'),
        launch_template_id=pulumi.get(__ret__, 'launch_template_id'),
        network_interfaces=pulumi.get(__ret__, 'network_interfaces'),
        project_name=pulumi.get(__ret__, 'project_name'),
        scheduled_instance=pulumi.get(__ret__, 'scheduled_instance'),
        security_enhancement_strategy=pulumi.get(__ret__, 'security_enhancement_strategy'),
        spot_price_limit=pulumi.get(__ret__, 'spot_price_limit'),
        spot_strategy=pulumi.get(__ret__, 'spot_strategy'),
        suffix_index=pulumi.get(__ret__, 'suffix_index'),
        tags=pulumi.get(__ret__, 'tags'),
        unique_suffix=pulumi.get(__ret__, 'unique_suffix'),
        user_data=pulumi.get(__ret__, 'user_data'),
        version_description=pulumi.get(__ret__, 'version_description'),
        version_number=pulumi.get(__ret__, 'version_number'),
        volumes=pulumi.get(__ret__, 'volumes'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_launch_template_version_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLaunchTemplateVersionResult]:
    """
    Data Source schema for Byteplus::ECS::LaunchtemplateVersion


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:ecs/getLaunchTemplateVersion:getLaunchTemplateVersion', __args__, opts=opts, typ=GetLaunchTemplateVersionResult)
    return __ret__.apply(lambda __response__: GetLaunchTemplateVersionResult(
        deployment_set_group_number=pulumi.get(__response__, 'deployment_set_group_number'),
        deployment_set_id=pulumi.get(__response__, 'deployment_set_id'),
        description=pulumi.get(__response__, 'description'),
        eip=pulumi.get(__response__, 'eip'),
        host_name=pulumi.get(__response__, 'host_name'),
        hpc_cluster_id=pulumi.get(__response__, 'hpc_cluster_id'),
        id=pulumi.get(__response__, 'id'),
        image_id=pulumi.get(__response__, 'image_id'),
        image_name=pulumi.get(__response__, 'image_name'),
        instance_charge_type=pulumi.get(__response__, 'instance_charge_type'),
        instance_name=pulumi.get(__response__, 'instance_name'),
        instance_type_id=pulumi.get(__response__, 'instance_type_id'),
        keep_image_credential=pulumi.get(__response__, 'keep_image_credential'),
        key_pair_name=pulumi.get(__response__, 'key_pair_name'),
        launch_template_id=pulumi.get(__response__, 'launch_template_id'),
        network_interfaces=pulumi.get(__response__, 'network_interfaces'),
        project_name=pulumi.get(__response__, 'project_name'),
        scheduled_instance=pulumi.get(__response__, 'scheduled_instance'),
        security_enhancement_strategy=pulumi.get(__response__, 'security_enhancement_strategy'),
        spot_price_limit=pulumi.get(__response__, 'spot_price_limit'),
        spot_strategy=pulumi.get(__response__, 'spot_strategy'),
        suffix_index=pulumi.get(__response__, 'suffix_index'),
        tags=pulumi.get(__response__, 'tags'),
        unique_suffix=pulumi.get(__response__, 'unique_suffix'),
        user_data=pulumi.get(__response__, 'user_data'),
        version_description=pulumi.get(__response__, 'version_description'),
        version_number=pulumi.get(__response__, 'version_number'),
        volumes=pulumi.get(__response__, 'volumes'),
        vpc_id=pulumi.get(__response__, 'vpc_id'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['MountPointArgs', 'MountPoint']

@pulumi.input_type
class MountPointArgs:
    def __init__(__self__, *,
                 file_system_id: pulumi.Input[builtins.str],
                 mount_point_name: pulumi.Input[builtins.str],
                 permission_group_id: pulumi.Input[builtins.str],
                 subnet_id: pulumi.Input[builtins.str],
                 vpc_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a MountPoint resource.
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        """
        pulumi.set(__self__, "file_system_id", file_system_id)
        pulumi.set(__self__, "mount_point_name", mount_point_name)
        pulumi.set(__self__, "permission_group_id", permission_group_id)
        pulumi.set(__self__, "subnet_id", subnet_id)
        pulumi.set(__self__, "vpc_id", vpc_id)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Input[builtins.str]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> pulumi.Input[builtins.str]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @mount_point_name.setter
    def mount_point_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "mount_point_name", value)

    @property
    @pulumi.getter(name="permissionGroupId")
    def permission_group_id(self) -> pulumi.Input[builtins.str]:
        """
        权限组 ID。
        """
        return pulumi.get(self, "permission_group_id")

    @permission_group_id.setter
    def permission_group_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "permission_group_id", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[builtins.str]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Input[builtins.str]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpc_id", value)


@pulumi.input_type
class _MountPointState:
    def __init__(__self__, *,
                 clients: Optional[pulumi.Input[Sequence[pulumi.Input['MountPointClientArgs']]]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_group: Optional[pulumi.Input['MountPointPermissionGroupArgs']] = None,
                 permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_name: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering MountPoint resources.
        :param pulumi.Input[builtins.str] created_time: 挂载点创建时间。
        :param pulumi.Input[builtins.str] domain: DNS 地址。
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] ip: 挂载点地址。
        :param pulumi.Input[builtins.str] mount_point_id: 挂载点 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input['MountPointPermissionGroupArgs'] permission_group: 挂载点绑定的权限组信息。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] status: 挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] subnet_name: 子网名称。
        :param pulumi.Input[builtins.str] updated_time: 挂载点更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        :param pulumi.Input[builtins.str] vpc_name: 私有网络名称。
        """
        if clients is not None:
            pulumi.set(__self__, "clients", clients)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if file_system_id is not None:
            pulumi.set(__self__, "file_system_id", file_system_id)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if mount_point_id is not None:
            pulumi.set(__self__, "mount_point_id", mount_point_id)
        if mount_point_name is not None:
            pulumi.set(__self__, "mount_point_name", mount_point_name)
        if permission_group is not None:
            pulumi.set(__self__, "permission_group", permission_group)
        if permission_group_id is not None:
            pulumi.set(__self__, "permission_group_id", permission_group_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if subnet_name is not None:
            pulumi.set(__self__, "subnet_name", subnet_name)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpc_id is not None:
            pulumi.set(__self__, "vpc_id", vpc_id)
        if vpc_name is not None:
            pulumi.set(__self__, "vpc_name", vpc_name)

    @property
    @pulumi.getter
    def clients(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['MountPointClientArgs']]]]:
        return pulumi.get(self, "clients")

    @clients.setter
    def clients(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['MountPointClientArgs']]]]):
        pulumi.set(self, "clients", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        DNS 地址。
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @file_system_id.setter
    def file_system_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "file_system_id", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点地址。
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @mount_point_id.setter
    def mount_point_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mount_point_id", value)

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @mount_point_name.setter
    def mount_point_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "mount_point_name", value)

    @property
    @pulumi.getter(name="permissionGroup")
    def permission_group(self) -> Optional[pulumi.Input['MountPointPermissionGroupArgs']]:
        """
        挂载点绑定的权限组信息。
        """
        return pulumi.get(self, "permission_group")

    @permission_group.setter
    def permission_group(self, value: Optional[pulumi.Input['MountPointPermissionGroupArgs']]):
        pulumi.set(self, "permission_group", value)

    @property
    @pulumi.getter(name="permissionGroupId")
    def permission_group_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        权限组 ID。
        """
        return pulumi.get(self, "permission_group_id")

    @permission_group_id.setter
    def permission_group_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_group_id", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        子网名称。
        """
        return pulumi.get(self, "subnet_name")

    @subnet_name.setter
    def subnet_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "subnet_name", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        挂载点更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @vpc_id.setter
    def vpc_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_id", value)

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")

    @vpc_name.setter
    def vpc_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpc_name", value)


@pulumi.type_token("bytepluscc:filenas/mountPoint:MountPoint")
class MountPoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        挂载点是 NAS 文件系统在网络环境中的连接点。NAS 文件系统需要挂载在计算节点中才能完成数据的访问与存储。挂载是将计算节点与 NAS 文件系统相连接的操作。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        file_nas_mount_point_demo = bytepluscc.filenas.MountPoint("FileNASMountPointDemo",
            file_system_id="enas-cnbja0f8*****",
            mount_point_name="test-1",
            permission_group_id="pgroup-01bc1182",
            subnet_id="subnet-btepcsc5*****",
            vpc_id="vpc-3nr6adcn064u8931*****")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:filenas/mountPoint:MountPoint example "file_system_id|mount_point_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MountPointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        挂载点是 NAS 文件系统在网络环境中的连接点。NAS 文件系统需要挂载在计算节点中才能完成数据的访问与存储。挂载是将计算节点与 NAS 文件系统相连接的操作。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        file_nas_mount_point_demo = bytepluscc.filenas.MountPoint("FileNASMountPointDemo",
            file_system_id="enas-cnbja0f8*****",
            mount_point_name="test-1",
            permission_group_id="pgroup-01bc1182",
            subnet_id="subnet-btepcsc5*****",
            vpc_id="vpc-3nr6adcn064u8931*****")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:filenas/mountPoint:MountPoint example "file_system_id|mount_point_id"
        ```

        :param str resource_name: The name of the resource.
        :param MountPointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MountPointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 file_system_id: Optional[pulumi.Input[builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
                 permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
                 subnet_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpc_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MountPointArgs.__new__(MountPointArgs)

            if file_system_id is None and not opts.urn:
                raise TypeError("Missing required property 'file_system_id'")
            __props__.__dict__["file_system_id"] = file_system_id
            if mount_point_name is None and not opts.urn:
                raise TypeError("Missing required property 'mount_point_name'")
            __props__.__dict__["mount_point_name"] = mount_point_name
            if permission_group_id is None and not opts.urn:
                raise TypeError("Missing required property 'permission_group_id'")
            __props__.__dict__["permission_group_id"] = permission_group_id
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            if vpc_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_id'")
            __props__.__dict__["vpc_id"] = vpc_id
            __props__.__dict__["clients"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["domain"] = None
            __props__.__dict__["ip"] = None
            __props__.__dict__["mount_point_id"] = None
            __props__.__dict__["permission_group"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["subnet_name"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["vpc_name"] = None
        super(MountPoint, __self__).__init__(
            'bytepluscc:filenas/mountPoint:MountPoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            clients: Optional[pulumi.Input[Sequence[pulumi.Input[Union['MountPointClientArgs', 'MountPointClientArgsDict']]]]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            domain: Optional[pulumi.Input[builtins.str]] = None,
            file_system_id: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            mount_point_id: Optional[pulumi.Input[builtins.str]] = None,
            mount_point_name: Optional[pulumi.Input[builtins.str]] = None,
            permission_group: Optional[pulumi.Input[Union['MountPointPermissionGroupArgs', 'MountPointPermissionGroupArgsDict']]] = None,
            permission_group_id: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            subnet_id: Optional[pulumi.Input[builtins.str]] = None,
            subnet_name: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpc_id: Optional[pulumi.Input[builtins.str]] = None,
            vpc_name: Optional[pulumi.Input[builtins.str]] = None) -> 'MountPoint':
        """
        Get an existing MountPoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] created_time: 挂载点创建时间。
        :param pulumi.Input[builtins.str] domain: DNS 地址。
        :param pulumi.Input[builtins.str] file_system_id: 文件系统 ID。
        :param pulumi.Input[builtins.str] ip: 挂载点地址。
        :param pulumi.Input[builtins.str] mount_point_id: 挂载点 ID。
        :param pulumi.Input[builtins.str] mount_point_name: 挂载点名称。
        :param pulumi.Input[Union['MountPointPermissionGroupArgs', 'MountPointPermissionGroupArgsDict']] permission_group: 挂载点绑定的权限组信息。
        :param pulumi.Input[builtins.str] permission_group_id: 权限组 ID。
        :param pulumi.Input[builtins.str] status: 挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        :param pulumi.Input[builtins.str] subnet_id: 子网 ID。
        :param pulumi.Input[builtins.str] subnet_name: 子网名称。
        :param pulumi.Input[builtins.str] updated_time: 挂载点更新时间。
        :param pulumi.Input[builtins.str] vpc_id: 私有网络 ID。
        :param pulumi.Input[builtins.str] vpc_name: 私有网络名称。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MountPointState.__new__(_MountPointState)

        __props__.__dict__["clients"] = clients
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["domain"] = domain
        __props__.__dict__["file_system_id"] = file_system_id
        __props__.__dict__["ip"] = ip
        __props__.__dict__["mount_point_id"] = mount_point_id
        __props__.__dict__["mount_point_name"] = mount_point_name
        __props__.__dict__["permission_group"] = permission_group
        __props__.__dict__["permission_group_id"] = permission_group_id
        __props__.__dict__["status"] = status
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["subnet_name"] = subnet_name
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpc_id"] = vpc_id
        __props__.__dict__["vpc_name"] = vpc_name
        return MountPoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def clients(self) -> pulumi.Output[Sequence['outputs.MountPointClient']]:
        return pulumi.get(self, "clients")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        挂载点创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[builtins.str]:
        """
        DNS 地址。
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="fileSystemId")
    def file_system_id(self) -> pulumi.Output[builtins.str]:
        """
        文件系统 ID。
        """
        return pulumi.get(self, "file_system_id")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        挂载点地址。
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="mountPointId")
    def mount_point_id(self) -> pulumi.Output[builtins.str]:
        """
        挂载点 ID。
        """
        return pulumi.get(self, "mount_point_id")

    @property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> pulumi.Output[builtins.str]:
        """
        挂载点名称。
        """
        return pulumi.get(self, "mount_point_name")

    @property
    @pulumi.getter(name="permissionGroup")
    def permission_group(self) -> pulumi.Output['outputs.MountPointPermissionGroup']:
        """
        挂载点绑定的权限组信息。
        """
        return pulumi.get(self, "permission_group")

    @property
    @pulumi.getter(name="permissionGroupId")
    def permission_group_id(self) -> pulumi.Output[builtins.str]:
        """
        权限组 ID。
        """
        return pulumi.get(self, "permission_group_id")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        挂载点状态。取值：Running：运行中。Creating：创建中。Updating：更新中。Error：异常。Deleting：删除中。DeleteError：删除异常。Deleted：已删除。Stopped：已停止。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[builtins.str]:
        """
        子网 ID。
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="subnetName")
    def subnet_name(self) -> pulumi.Output[builtins.str]:
        """
        子网名称。
        """
        return pulumi.get(self, "subnet_name")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        挂载点更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> pulumi.Output[builtins.str]:
        """
        私有网络 ID。
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vpcName")
    def vpc_name(self) -> pulumi.Output[builtins.str]:
        """
        私有网络名称。
        """
        return pulumi.get(self, "vpc_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCustomizedCfgResult',
    'AwaitableGetCustomizedCfgResult',
    'get_customized_cfg',
    'get_customized_cfg_output',
]

@pulumi.output_type
class GetCustomizedCfgResult:
    """
    A collection of values returned by getCustomizedCfg.
    """
    def __init__(__self__, created_time=None, customized_cfg_content=None, customized_cfg_id=None, customized_cfg_name=None, description=None, id=None, listeners=None, project_name=None, status=None, tags=None, updated_time=None):
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if customized_cfg_content and not isinstance(customized_cfg_content, str):
            raise TypeError("Expected argument 'customized_cfg_content' to be a str")
        pulumi.set(__self__, "customized_cfg_content", customized_cfg_content)
        if customized_cfg_id and not isinstance(customized_cfg_id, str):
            raise TypeError("Expected argument 'customized_cfg_id' to be a str")
        pulumi.set(__self__, "customized_cfg_id", customized_cfg_id)
        if customized_cfg_name and not isinstance(customized_cfg_name, str):
            raise TypeError("Expected argument 'customized_cfg_name' to be a str")
        pulumi.set(__self__, "customized_cfg_name", customized_cfg_name)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listeners and not isinstance(listeners, list):
            raise TypeError("Expected argument 'listeners' to be a list")
        pulumi.set(__self__, "listeners", listeners)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        个性化配置的创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="customizedCfgContent")
    def customized_cfg_content(self) -> builtins.str:
        """
        个性化配置项内容。具体规则如下：长度不超过4096字符。空格和分号需要转义。不同的配置项之间通过";\\r\\n"分隔，配置项不能重复。当前支持的配置项有ssl*protocols、ssl*ciphers、client*max*body*size、keepalive*timeout、proxy*request*buffering、proxy*connect*timeout、add*header、client*header*timeout、proxy*read*timeout、proxy*send*timeout、client*body*timeout、send*timeout和ssl*verify*depth。详细信息参见官网文档。
        """
        return pulumi.get(self, "customized_cfg_content")

    @property
    @pulumi.getter(name="customizedCfgId")
    def customized_cfg_id(self) -> builtins.str:
        """
        个性化配置的 ID 。
        """
        return pulumi.get(self, "customized_cfg_id")

    @property
    @pulumi.getter(name="customizedCfgName")
    def customized_cfg_name(self) -> builtins.str:
        """
        个性化配置的名字。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、点号（.）、下划线（_）和短横线（-）。长度限制为1 ～ 128个字符。
        """
        return pulumi.get(self, "customized_cfg_name")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        个性化配置的描述。具体规则如下：不能以http://或https://开头。必须以字母或中文开头，可包含数字、英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）长度限制为1 ～ 255个字符。不填默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def listeners(self) -> Sequence['outputs.GetCustomizedCfgListenerResult']:
        """
        个性化配置关联的监听器列表。
        """
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        个性化配置所属项目名称。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        个性化配置状态。包括Active、Configuring、Creating或者Deleting。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetCustomizedCfgTagResult']:
        """
        标签列表。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        个性化配置的最近操作时间。
        """
        return pulumi.get(self, "updated_time")


class AwaitableGetCustomizedCfgResult(GetCustomizedCfgResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCustomizedCfgResult(
            created_time=self.created_time,
            customized_cfg_content=self.customized_cfg_content,
            customized_cfg_id=self.customized_cfg_id,
            customized_cfg_name=self.customized_cfg_name,
            description=self.description,
            id=self.id,
            listeners=self.listeners,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            updated_time=self.updated_time)


def get_customized_cfg(id: Optional[builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCustomizedCfgResult:
    """
    Data Source schema for Byteplus::ALB::CustomizedCfg


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:alb/getCustomizedCfg:getCustomizedCfg', __args__, opts=opts, typ=GetCustomizedCfgResult).value

    return AwaitableGetCustomizedCfgResult(
        created_time=pulumi.get(__ret__, 'created_time'),
        customized_cfg_content=pulumi.get(__ret__, 'customized_cfg_content'),
        customized_cfg_id=pulumi.get(__ret__, 'customized_cfg_id'),
        customized_cfg_name=pulumi.get(__ret__, 'customized_cfg_name'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        listeners=pulumi.get(__ret__, 'listeners'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_time=pulumi.get(__ret__, 'updated_time'))
def get_customized_cfg_output(id: Optional[pulumi.Input[builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCustomizedCfgResult]:
    """
    Data Source schema for Byteplus::ALB::CustomizedCfg


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:alb/getCustomizedCfg:getCustomizedCfg', __args__, opts=opts, typ=GetCustomizedCfgResult)
    return __ret__.apply(lambda __response__: GetCustomizedCfgResult(
        created_time=pulumi.get(__response__, 'created_time'),
        customized_cfg_content=pulumi.get(__response__, 'customized_cfg_content'),
        customized_cfg_id=pulumi.get(__response__, 'customized_cfg_id'),
        customized_cfg_name=pulumi.get(__response__, 'customized_cfg_name'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        listeners=pulumi.get(__response__, 'listeners'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_time=pulumi.get(__response__, 'updated_time')))
